@@ -3,13 +3,14 @@
 # @Email:  kramer@mpi-cbg.de
 # @Project: go-with-the-flow
 # @Last modified by:    Felix Kramer
-# @Last modified time: 2021-05-23T23:58:52+02:00
+# @Last modified time: 2021-05-24T00:03:20+02:00
 # @License: MIT
 
 import networkx as nx
 import numpy as np
 import kirchhoff.init_crystal
 from scipy.spatial import Voronoi
+import kirchhoff.init_crystal  as init_crystal
 
 def init_dual_minsurf_graphs(dual_type,num_periods):
 
@@ -31,7 +32,7 @@ def init_dual_minsurf_graphs(dual_type,num_periods):
 
     return dual_graph
 
-class networkx_dual(kirchhoff.init_crystal.networkx_crystal,object):
+class networkx_dual(init_crystal.networkx_crystal,object):
 
     def __init__(self):
 
